# CreateSessionAndTokenRequest

A request to create a session and a token associated with the session

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**create_token_request** | [**CreateTokenRequest**](CreateTokenRequest.md) |  | 
**session** | [**Session**](Session.md) |  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


